@@ -1,16 +1,17 @@
 __all__ = [
     'list_invoices_response',
     'get_checkout_boleto_payment_response',
-    'create_card_options_request',
+    'update_price_bracket_request',
     'update_subscription_billing_date_request',
     'list_charges_response',
     'list_subscriptions_response',
     'paging_response',
+    'create_card_options_request',
     'list_transactions_response',
     'get_plan_item_response',
+    'list_cards_response',
     'get_phones_response',
     'create_card_token_request',
-    'list_cards_response',
     'get_pricing_scheme_response',
     'get_price_bracket_response',
     'get_token_response',
@@ -41,24 +42,23 @@ __all__ = [
     'create_price_bracket_request',
     'get_card_token_response',
     'get_checkout_card_installment_options_response',
-    'create_pricing_scheme_request',
     'create_cancel_subscription_request',
     'update_card_request',
     'create_plan_request',
     'create_bank_transfer_payment_request',
+    'create_pricing_scheme_request',
     'create_phones_request',
     'create_voucher_payment_request',
     'create_checkout_boleto_payment_request',
     'update_charge_due_date_request',
-    'list_subscription_items_response',
     'create_access_token_request',
     'get_phone_response',
+    'list_subscription_items_response',
     'list_order_response',
     'list_addresses_response',
     'get_discount_response',
     'get_customer_response',
     'create_address_request',
-    'update_price_bracket_request',
     'create_subscription_item_request',
     'create_order_request',
     'get_gateway_response_response',
@@ -69,82 +69,82 @@ __all__ = [
     'update_charge_payment_method_request',
     'get_recipient_response',
     'update_recipient_request',
+    'get_gateway_recipient_response',
+    'list_increments_response',
     'create_anticipation_request',
     'get_anticipation_limits_response',
     'get_invoice_item_response',
     'create_discount_request',
     'get_card_response',
-    'get_gateway_recipient_response',
-    'list_increments_response',
     'create_bank_account_request',
     'get_balance_response',
     'update_order_item_request',
     'create_boleto_payment_request',
     'list_anticipation_response',
     'update_address_request',
-    'get_subscription_item_response',
     'get_location_response',
+    'get_subscription_item_response',
     'create_transfer_settings_request',
-    'get_gateway_error_response',
     'create_transfer_request',
-    'get_billing_address_response',
+    'get_gateway_error_response',
     'list_transfer_response',
     'create_usage_request',
     'create_payment_authentication_request',
-    'create_increment_request',
     'update_invoice_status_request',
-    'get_anticipation_limit_response',
     'get_usage_response',
     'create_subscription_request',
     'create_apple_pay_request',
+    'get_anticipation_limit_response',
     'update_customer_request',
     'get_subscription_response',
     'get_period_response',
     'create_debit_card_payment_request',
     'create_apple_pay_header_request',
-    'get_transfer_response',
     'create_location_request',
     'update_order_status_request',
     'create_credit_card_payment_request',
     'list_discounts_response',
     'create_recipient_request',
+    'get_transfer_response',
     'list_recipient_response',
     'get_device_response',
     'create_payment_request',
     'get_transaction_response',
     'update_recipient_bank_account_request',
     'update_transfer_settings_request',
-    'create_cancel_charge_request',
-    'update_subscription_start_at_request',
-    'create_transaction_report_file_request',
-    'create_card_request',
-    'create_emv_data_dukpt_decrypt_request',
-    'get_withdraw_target_response',
-    'get_charges_summary_response',
-    'create_private_label_payment_request',
-    'update_automatic_anticipation_settings_request',
+    'get_billing_address_response',
+    'create_increment_request',
     'create_cash_payment_request',
-    'create_confirm_payment_request',
+    'create_cancel_charge_request',
     'create_shipping_request',
     'get_checkout_credit_card_payment_response',
     'create_charge_request',
     'create_transfer',
-    'get_checkout_debit_card_payment_response',
-    'get_anticipation_response',
-    'create_automatic_anticipation_settings_request',
+    'create_transaction_report_file_request',
+    'create_card_request',
+    'create_emv_data_dukpt_decrypt_request',
+    'get_withdraw_target_response',
     'create_cancel_charge_split_rules_request',
-    'get_split_response',
+    'update_subscription_start_at_request',
     'create_pix_payment_request',
+    'get_charges_summary_response',
+    'create_private_label_payment_request',
+    'update_automatic_anticipation_settings_request',
+    'get_split_response',
     'list_transactions_files_response',
     'create_emv_data_tlv_decrypt_request',
     'create_emv_decrypt_request',
     'get_withdraw_source_response',
+    'create_confirm_payment_request',
+    'get_checkout_debit_card_payment_response',
+    'get_anticipation_response',
+    'create_automatic_anticipation_settings_request',
+    'update_subscription_minimum_price_request',
     'create_google_pay_request',
     'update_subscription_payment_method_request',
     'create_antifraud_request',
     'get_checkout_bank_transfer_payment_response',
     'get_bank_account_response',
-    'update_subscription_minimum_price_request',
     'create_order_item_request',
     'create_split_options_request',
     'get_transaction_report_file_response',
@@ -153,24 +153,25 @@ __all__ = [
     'list_transfers',
     'pix_additional_information',
     'get_shipping_response',
+    'update_current_cycle_end_date_request',
     'create_checkout_bank_transfer_request',
     'create_card_payment_contactless_request',
     'create_customer_request',
     'get_transfer_target_response',
     'list_withdrawals',
-    'update_current_cycle_end_date_request',
-    'create_checkout_credit_card_payment_request',
     'get_checkout_payment_response',
     'create_emv_data_decrypt_request',
     'get_withdraw_response',
     'get_automatic_anticipation_response',
+    'create_checkout_payment_request',
+    'create_checkout_credit_card_payment_request',
+    'get_transfer',
     'create_split_request',
     'update_current_cycle_status_request',
     'create_invoice_request',
     'get_transfer_settings_response',
-    'create_checkout_payment_request',
     'create_period_request',
-    'get_transfer',
+    'get_payment_authentication_response',
     'get_three_d_secure_response',
     'create_google_pay_header_request',
     'get_order_item_response',
@@ -178,7 +179,6 @@ __all__ = [
     'create_card_payment_contactless_poi_request',
     'create_withdraw_request',
     'get_split_options_response',
-    'get_payment_authentication_response',
     'list_charge_transactions_response',
     'list_cycles_response',
     'get_invoice_response',
@@ -188,8 +188,9 @@ __all__ = [
     'update_subscription_due_days_request',
     'create_checkout_pix_payment_request',
     'get_checkout_pix_payment_response',
-    'cancel_split_request',
     'create_subscription_split_request',
     'update_subscription_split_request',
     'get_subscription_split_response',
+    'get_pix_payer_response',
+    'get_pix_bank_account_response',
 ]
\ No newline at end of file
